@@ -50,7 +50,14 @@ class Flow(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Flow.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["FlowProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -112,7 +119,16 @@ class FlowProps:
         :param role_arn: Property roleArn: Optional parameter, the resource descriptor information required for the execution of the flow, used to perform the assume role during FnF execution.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FlowProps.__init__)
+            def stub(
+                *,
+                definition: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                request_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                role_arn: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
@@ -207,7 +223,14 @@ class RosFlow(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosFlow.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosFlowProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -223,7 +246,9 @@ class RosFlow(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosFlow._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -284,7 +309,11 @@ class RosFlow(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosFlow, "definition").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "definition", value)
 
@@ -296,7 +325,9 @@ class RosFlow(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosFlow, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -311,7 +342,11 @@ class RosFlow(
     @name.setter
     def name(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosFlow, "name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -331,7 +366,11 @@ class RosFlow(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosFlow, "description").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -351,7 +390,11 @@ class RosFlow(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosFlow, "request_id").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "requestId", value)
 
@@ -371,7 +414,11 @@ class RosFlow(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosFlow, "role_arn").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "roleArn", value)
 
@@ -406,7 +453,16 @@ class RosFlowProps:
         :param role_arn: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosFlowProps.__init__)
+            def stub(
+                *,
+                definition: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                request_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                role_arn: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
@@ -505,7 +561,14 @@ class RosSchedule(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosSchedule.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosScheduleProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -521,7 +584,9 @@ class RosSchedule(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosSchedule._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -574,7 +639,11 @@ class RosSchedule(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSchedule, "cron_expression").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cronExpression", value)
 
@@ -586,7 +655,9 @@ class RosSchedule(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSchedule, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -604,7 +675,11 @@ class RosSchedule(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSchedule, "flow_name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "flowName", value)
 
@@ -622,7 +697,11 @@ class RosSchedule(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSchedule, "schedule_name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "scheduleName", value)
 
@@ -642,7 +721,11 @@ class RosSchedule(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSchedule, "description").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -662,7 +745,11 @@ class RosSchedule(
         value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSchedule, "enable").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enable", value)
 
@@ -682,7 +769,11 @@ class RosSchedule(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSchedule, "payload").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "payload", value)
 
@@ -720,7 +811,17 @@ class RosScheduleProps:
         :param payload: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosScheduleProps.__init__)
+            def stub(
+                *,
+                cron_expression: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                flow_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                schedule_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                enable: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                payload: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument cron_expression", value=cron_expression, expected_type=type_hints["cron_expression"])
             check_type(argname="argument flow_name", value=flow_name, expected_type=type_hints["flow_name"])
             check_type(argname="argument schedule_name", value=schedule_name, expected_type=type_hints["schedule_name"])
@@ -834,7 +935,14 @@ class Schedule(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Schedule.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["ScheduleProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -893,7 +1001,17 @@ class ScheduleProps:
         :param payload: Property payload: Payload.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ScheduleProps.__init__)
+            def stub(
+                *,
+                cron_expression: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                flow_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                schedule_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                enable: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                payload: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument cron_expression", value=cron_expression, expected_type=type_hints["cron_expression"])
             check_type(argname="argument flow_name", value=flow_name, expected_type=type_hints["flow_name"])
             check_type(argname="argument schedule_name", value=schedule_name, expected_type=type_hints["schedule_name"])
